==> mad_notifications-3.0.2.tar.gz: mad_notifications-3.0.2/README.md <==
# Mad Notifications

Mad Notifications app for django to send notifications to the user

## Quick start

1. Add "mad_notifications" to your INSTALLED_APPS setting like this:

    ```python
    INSTALLED_APPS = [
        ...
        'mad_notifications',
    ]
    ```

2. Include the notifications URLconf in your project urls.py like this:

    ```python
    path('notifications/', include('mad_notifications.api.urls')),
    ```

3. Run `python manage.py migrate` to create the notifications models.

## Usage

### Shorthand method

```python
from mad_notifications.shorthand import newNotification
# create and send
return newNotification(
    user, # django user object
    title, # string
    content, # string
    template_slug = None, # slug from mad_notification.EmailTemplate
    data = {}, # dict
    actions = {} # dict
)
```

### Notification Class

```python
from mad_notifications.notification import Notification
# create a notification
notification = Notification(
    user = user,
    title = "New Order",
    content = "You have a new order!",
    data = {
        'order': order_data,
    },
    actions = {
        'click_action': "ORDER_SCREEN"
    },
    template = email_template, # mad_notification.EmailTemplate Object
)
# send the notification
notification.notify()
```

## Overriding default

```python
MAD_NOTIFICATIONS = {
    "FIREBASE_MOBILE_PUSH_NOTIFICATION_CLASS": "mad_notifications.senders.firebase.FirebaseMobilePushNotification",
    "EMAIL_NOTIFICATION_CLASS": "mad_notifications.senders.email.EmailNotification",
}
```

## Developer Guide

### Setting up a new provider

Create logic in `~/senders/PROVIDER.py` and call via tasks in `~/notify/PROVIDER.py`

==> mad_notifications-5.0.3.tar.gz: mad_notifications-5.0.3/README.md <==
# Mad Notifications

Mad Notifications app for django to send notifications to the user

## Quick start

1. Add "mad_notifications" to your INSTALLED_APPS setting like this:

    ```python
    INSTALLED_APPS = [
        ...
        'mad_notifications',
    ]
    ```

2. Include the notifications URLconf in your project urls.py like this:

    ```python
    path('notifications/', include('mad_notifications.api.urls')),
    ```

3. Run `python manage.py migrate` to create the notifications models.

## Usage

### Shorthand method

```python
from mad_notifications.shorthand import newNotification
# create and send
return newNotification(
    user, # django user object
    title, # string
    content, # string
    template_slug = None, # slug from mad_notification.NotificationTemplate
    data = {}, # dict
    actions = {} # dict
)
```

### Notification Class

```python
from mad_notifications.notification import Notification
# create a notification
notification = Notification(
    user = user,
    title = "New Order",
    content = "You have a new order!",
    data = {
        'order': order_data,
    },
    actions = {
        'click_action': "ORDER_SCREEN"
    },
    template = email_template, # mad_notification.EmailTemplate Object
)
# send the notification
notification.notify()
```

## Overriding default

```python
MAD_NOTIFICATIONS = {
    "FIREBASE_MOBILE_PUSH_NOTIFICATION_CLASS": "mad_notifications.senders.firebase.FirebaseMobilePushNotification",
    "EMAIL_NOTIFICATION_CLASS": "mad_notifications.senders.email.EmailNotification",
}
```

## Developer Guide

### Setting up a new provider

Create logic in `~/senders/PROVIDER.py` and call via tasks in `~/notify/PROVIDER.py`
